//
//  Test_v3norm.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_v3norm_h
#define BulletTest_Test_v3norm_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_v3norm(void);

#ifdef __cplusplus
}
#endif

#endif
